from distutils.core import setup

setup(
	name="palindrome",
	version="1.0.0",
	py_modules=["palindrome"],
	author="Dhruba Karmakar",
	author_email="medhrk@gmail.com",
	url="http://www.bagsandwallet.weebly.com",
	description="A simple palindrome checker",
)



def reverse(text):
    return text[::-1]
text = input("Enter a string ")
try:
    text=str(text)
except:
    print ("enter only string value")
    exit()
if text==reverse(text):
    print ("palindrome!!")
else:
    print ("not a palindrome")
    
